/*
 *  Gtk-Parted - a front-end for libparted
 *  Copyright (C) 2000, 2001  Damien Genet
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <string.h>

#include <glib.h>

#include "ctype.h"

gboolean
str_is_empty                           (gchar            *string)
{	
	g_return_val_if_fail (string, TRUE);

	for (; string != '\0'; string++) {
		if (!isspace (*string))
			return FALSE;
	}

	return TRUE;
}

gboolean
str_is_shell_comment_or_empty          (gchar            *string)
{	
	g_return_val_if_fail (string, TRUE);

	for (; string != '\0'; string++) {
		if (*string == '#')
			return TRUE;
		else if (!isspace (*string))
			return FALSE;
	}

	return TRUE;
}

gboolean
str_are_equal                          (gchar            *string1,
                                        gchar            *string2)
{
	if (string1 == string2)
		return TRUE;
	else if ( (string1 && !string2)
	          || (!string1 && string2) )
		return FALSE;
	else if (strcmp (string1, string2))
		return FALSE;
	else
		return TRUE;
}

gchar*
str_get_nth_word                       (gchar            *string,
                                        guint             nb,
                                        guint            *length)
{
	gboolean 	 last_is_space = TRUE;
	guint		 word_nb = 0;
	
	g_return_val_if_fail (string, NULL);
	g_return_val_if_fail (nb, NULL);
	g_return_val_if_fail (length, NULL);
	
	*length = 0;
	
	for (; string != '\0'; string++) {
		if (isspace (*string)) {
			if (word_nb == nb)
				return string - *length;
			last_is_space = TRUE;
		} else { 
			if (last_is_space)
				word_nb++;
			if (word_nb == nb)
				(*length)++;
			last_is_space = FALSE;
		}
	}
	
	/*
	 * nothing found
	 */
	return NULL;
}

gchar*
str_dup_get_nth_word                   (gchar            *string,
                                        guint             nb)
{
	gchar	*word;
	guint	 length;
	
	g_return_val_if_fail (string, NULL);
	g_return_val_if_fail (nb, NULL);

	if ( !(word = str_get_nth_word (string, nb, &length)) )
		return NULL;
	
	word = g_strndup (word, length);
	
	return word;
}
